# Release History

## 1.0.1 (2026-03-13)

### Other Changes

- This package has been deprecated and will no longer be maintained after 03-13-2026. This package will only receive security fixes until 03-13-2026.

## 1.0.0 (2025-04-21)

### Features Added

  - Client `NeonPostgresMgmtClient` added operation group `models`
  - Client `NeonPostgresMgmtClient` added operation group `projects`
  - Client `NeonPostgresMgmtClient` added operation group `branches`
  - Client `NeonPostgresMgmtClient` added operation group `computes`
  - Client `NeonPostgresMgmtClient` added operation group `neon_databases`
  - Client `NeonPostgresMgmtClient` added operation group `neon_roles`
  - Client `NeonPostgresMgmtClient` added operation group `endpoints`
  - Model `OrganizationProperties` added property `project_properties`
  - Added model `Attributes`
  - Added model `Branch`
  - Added model `BranchProperties`
  - Added model `Compute`
  - Added model `ComputeProperties`
  - Added model `ConnectionUriProperties`
  - Added model `DefaultEndpointSettings`
  - Added model `Endpoint`
  - Added model `EndpointProperties`
  - Added enum `EndpointType`
  - Added model `NeonDatabase`
  - Added model `NeonDatabaseProperties`
  - Added model `NeonRole`
  - Added model `NeonRoleProperties`
  - Added model `PgVersion`
  - Added model `PgVersionsResult`
  - Added model `Project`
  - Added model `ProjectProperties`
  - Added model `ProxyResource`
  - Operation group `OrganizationsOperations` added method `get_postgres_versions`
  - Added operation group `BranchesOperations`
  - Added operation group `ComputesOperations`
  - Added operation group `EndpointsOperations`
  - Added operation group `ModelsOperations`
  - Added operation group `NeonDatabasesOperations`
  - Added operation group `NeonRolesOperations`
  - Added operation group `ProjectsOperations`

## 1.0.0b1 (2024-12-03)

### Other Changes

  - Initial version
